SystemOrganization addCategory: #'WebStore-Core'!
SystemOrganization addCategory: #'WebStore-TestSite'!
SystemOrganization addCategory: #'WebStore-Components'!
SystemOrganization addCategory: #'WebStore-Admin'!
SystemOrganization addCategory: #'WebStore-Tests'!
SystemOrganization addCategory: #'WebStore-Util'!

Object subclass: #WSImage
	instanceVariableNames: 'uuid'
	classVariableNames: 'Thumb Medium'
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSImage class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 22:42'!
fromStream: aStream
	^self basicNew
		initialize;
		generateImagesFrom: (ImageReadWriter formFromStream: aStream);
		yourself.
	! !

!WSImage class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 22:27'!
initialize
	super initialize.
	Thumb := 100@100.
	Medium := 300@300.! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 22:20'!
fullsize
	^uuid printString, '-full'! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 22:25'!
generateImagesFrom: aForm.
	(aForm scaledToSize: Thumb) writeJPEGfileNamed: self thumbnail.
	(aForm scaledToSize: Medium) writeJPEGfileNamed: self medium.
	aForm writeJPEGfileNamed: self fullsize.! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 22:19'!
initialize
	super initialize.
	uuid := UUID new.! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 22:20'!
medium
	^uuid printString, '-med'! !

!WSImage methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 23:25'!
thumbnail
	^uuid printString, '-thumb'! !

Object subclass: #WSProduct
	instanceVariableNames: 'name description price images preview'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:20'!
addImage: anImage
	images add: anImage.
	images size = 1 ifTrue: [preview := anImage]! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 07:29'!
description
	^description! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 07:30'!
description: aDescription
	description := aDescription.! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 21:22'!
images
	^images! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:54'!
initialize
	images := OrderedCollection new.! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:53'!
name
	^name.! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:53'!
name: aName
	name := aName.! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:19'!
preview
	^preview! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:24'!
preview: anImage
	(images includes: anImage) ifFalse: [
		self error: 'Preview image must be one of the product''s images'
	].
	preview := anImage! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 07:32'!
price
	^price! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 07:32'!
price: priceInCents
	price := priceInCents! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:20'!
priceInDollars
	^(price / 100) asFloat! !

!WSProduct methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:22'!
removeImage: anImage
	images remove: anImage.
	preview = anImage ifTrue: [
		preview := images isEmpty ifTrue: [nil] ifFalse: [images first]]! !

Object subclass: #WSProductPreview
	instanceVariableNames: 'product parent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSProductPreview class methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 18:27'!
for: aProduct on: parent
	^self basicNew 
		product: aProduct; 
		parent: parent;
		initialize;
		yourself.! !

!WSProductPreview methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 17:48'!
initialize
	super initialize.! !

!WSProductPreview methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 18:26'!
parent: aComponent
	parent := aComponent! !

!WSProductPreview methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 17:48'!
product: aProduct
	product := aProduct.! !

!WSProductPreview methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 14:04'!
renderContentOn: html
	html paragraph: '$', product priceInDollars printString.
	html div: [html heading level: 3; with: [
			html anchor callback: [ parent call: (WSProductDetails for: product) ]; with: product name]]! !

Object subclass: #WSRule
	instanceVariableNames: 'rule message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSRule class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:01'!
rule: aBlock message: aMessage
	^self basicNew
		rule: aBlock;
		message: aMessage;
		initialize;
		yourself.! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:02'!
message
	^message! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:02'!
message: aString
	message := aString! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:02'!
rule
	^rule! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:01'!
rule: aBlock
	rule :=  aBlock! !

!WSRule methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:04'!
testRule: value
	^rule value: value! !

Object subclass: #WSStore
	instanceVariableNames: 'products'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Core'!

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:48'!
addProduct: aProduct
	products add: aProduct.! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 14:45'!
deleteProduct: aProduct
	products remove: aProduct! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:44'!
initialize
	super initialize.
	products := OrderedCollection new.! !

!WSStore methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:49'!
products
	^OrderedCollection new addAll: products.! !

WAComponent subclass: #TestSite
	instanceVariableNames: 'store products'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-TestSite'!

!TestSite class methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 12:53'!
canBeRoot
	^true! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:34'!
children
	^Array with: products.! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 17:42'!
initialize
	| rs |
	super initialize.
	rs := ReferenceStream fileNamed: 'demo_store'.
	store := rs next.
	rs close.
	products := WSProductList store: store.! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 18:35'!
renderContentOn: html
	html heading: 'Emma''s Store'.
	html div id: 'nav';with: [
		html unorderedList with: [
			html listItem: [ html anchor callback: []; with: 'Home'].
			html listItem: [ html anchor callback: []; with: 'A link']
		]].
	html div id: 'content';with:products! !

WAComponent subclass: #WSField
	instanceVariableNames: 'value selector receiver tag label rules'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:50'!
image
	^WSImageField new.! !

!WSField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:57'!
largeText
	^self basicNew
		tagType:  #textArea;
		initialize;
		yourself.! !

!WSField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:15'!
money
	^WSMoneyField new.! !

!WSField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:13'!
text
	^self basicNew
		tagType:  #textInput;
		initialize;
		yourself.! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:05'!
addRule: aBlock withDescription: desc.
	rules add: (WSRule rule: aBlock message: desc)! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:07'!
beRequired
	"Nil is allowed, because the only time it'll be nil is when the form is first rendered"
	self addRule: [ :v| v isNil or: [v notEmpty]] withDescription: label, ' is a required field'.! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 17:25'!
initialize
	super initialize.
	rules := OrderedCollection new.! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 17:05'!
label: aString
	label := aString! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:06'!
messages
	^rules select: [ :r | (r testRule: value) not] thenCollect: [ :r | r message ] ! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:14'!
on: aSelector of: aReceiver
	selector := aSelector.
	receiver := aReceiver.
	self setValue! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 17:11'!
renderContentOn: html
	html div class: (self valid ifFalse: ['error']); with: [
		| id |
		id := html nextId.
		html label for: id; with: label.
		(html perform: tag) 
			id: id;
			callback: [ :v| value := v];
			value: value
		]! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:08'!
save
	receiver perform: selector asMutator with: value! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:14'!
setValue
	value := receiver perform: selector! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 17:01'!
tagType: symbol
	tag := symbol! !

!WSField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:06'!
valid
	^rules allSatisfy: [ :r | r  testRule: value ]! !

WSField subclass: #WSImageField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSImageField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:55'!
new
	^self basicNew
		tagType: #fileUpload;
		initialize;
		yourself.! !

!WSImageField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:58'!
setValue
	"Can't do anything sensible here"! !

WSField subclass: #WSMoneyField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Util'!

!WSMoneyField class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:18'!
new
	^self basicNew
		tagType: #textInput;
		initialize;
		yourself.! !

!WSMoneyField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:18'!
save
	receiver perform: selector asMutator with: ((value asNumber) * 100) asInteger! !

!WSMoneyField methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:22'!
setValue
	value := receiver perform: selector.
	value ifNotNil: [ value := (value / 100) asFloat printString]! !

WAComponent subclass: #WSImageEditor
	instanceVariableNames: 'image imageField'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:57'!
children
	^Array with: imageField! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 23:23'!
image: aWAFile
	image := WSImage fromStream: (ReadStream on: aWAFile contents asByteArray)! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:52'!
initialize
	super initialize.
	imageField := WSField image
		label: 'Select an Image';
		on: #image of: self;
		yourself! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 22:00'!
renderContentOn: html
	html form multipart; with: [
		html render: imageField.
		html div: [
			html cancelButton callback: [self answer: nil]; value: 'Cancel'.
			html submitButton callback: [self save]; value: 'Preview'.
			html submitButton callback: [self saveAndAnswer]; value: 'Done'	
		]
	].
	image ifNotNil: [
		html div: [
			html image resourceUrl: image thumbnail.
			html image resourceUrl: image medium.
		]		
	]

! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 22:01'!
save
	imageField valid ifTrue: [imageField save].	! !

!WSImageEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 23:29'!
saveAndAnswer
	self save.
	self answer: image! !

WAComponent subclass: #WSImageManager
	instanceVariableNames: 'product'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSImageManager class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:27'!
for: aProduct
	^self basicNew
		product: aProduct;
		initialize;
		yourself.! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 23:32'!
addImage
	|i| 
	i := self call: WSImageEditor new.
	i ifNotNil: [product addImage: i].! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:43'!
initialize
	super initialize! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:28'!
product: aProduct
	product := aProduct! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 23:31'!
renderContentOn: html
	html anchor callback: [self addImage]; with: 'Add Image'.
	self renderImageListOn: html.! !

!WSImageManager methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 23:33'!
renderImageListOn: html
	product images do: [:i |
		html div: [
			html div 
				class: (product preview = i ifTrue: ['preview']); 
				with: [html image resourceUrl: i thumbnail].
			html div: [
				html anchor callback:  [product preview: i]; with: 'Set as Preview'.
				html text: ' '.
				html anchor callback: [self edit: i]; with: 'Edit'].
				html text: ' '.
				html anchor callback: [self delete: i]; with: 'Delete']]! !

WAComponent subclass: #WSManageProducts
	instanceVariableNames: 'store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSManageProducts class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 12:02'!
store: aStore
	^self basicNew
		store: aStore;
		initialize;
		yourself! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:07'!
addProduct
	| p |
	p := self call: WSProductEditor new.
	p ifNotNil: [	store addProduct: p]! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 14:09'!
deleteProduct: p
	(self confirm: 'Really delete ',p name, '?') ifTrue: [
		store deleteProduct: p	
	]! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:01'!
editProduct: aProduct 
	self call: (WSProductEditor product: aProduct)! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:48'!
initialize
	super initialize! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:24'!
manageImages: aProduct
	self call: (WSImageManager for: aProduct)! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 12:11'!
renderActionsOn: html
	html div: [
		html anchor callback: [ self addProduct]; with: 'Add Product'].! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 12:06'!
renderContentOn: html

	self renderStatsOn: html.
	self renderActionsOn: html.
	self renderProductListOn: html.

	html anchor callback: [ self answer ]; with: 'back'.! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:23'!
renderProductListOn: html
	html table: [
		html tableRow: [
			html tableHeading.
			html tableHeading: 'Name'.
			html tableHeading: 'Price'.
			html tableHeading: 'Actions'	].
		store products do: [ :p| html tableRow: [
			html tableData.		
			html tableData: p name.
			html tableData: p priceInDollars printString.
			html tableData: [ 
				html anchor callback: [ self deleteProduct: p ]; with: 'Delete'.
				html space.
				html anchor callback: [self editProduct: p]; with: 'Edit'.
				html space.
				html anchor callback: [self manageImages: p ]; with: 'Images']]]]! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:25'!
renderStatsOn: html
	html div: [
		html paragraph: store products size printString, ' products']! !

!WSManageProducts methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 12:03'!
store: aStore
	store := aStore! !

WAComponent subclass: #WSProductDetails
	instanceVariableNames: 'product'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSProductDetails class methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 17:54'!
for: aProduct
	^self basicNew
		product: aProduct;
		initialize;
		yourself.! !

!WSProductDetails methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:47'!
initialize
	super initialize.! !

!WSProductDetails methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 17:55'!
product: aProduct
	product := aProduct.! !

!WSProductDetails methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 18:34'!
renderContentOn: html
	html heading level: 2; with: product name.
	html paragraph with: '$', (product price / 100) asInteger printString.
	html paragraph with: product description.
	html anchor callback: [ self answer ]; with: 'Back'.! !

WAComponent subclass: #WSProductEditor
	instanceVariableNames: 'product fields'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSProductEditor class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 18:55'!
new
	^self basicNew
		product: (WSProduct new);
		initialize;
		yourself.! !

!WSProductEditor class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 15:49'!
product: aProduct
	^self basicNew
		product: aProduct;
		initialize;
		yourself.! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 15:39'!
children
	^fields! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 16:47'!
initialize
	super initialize.
	self setupFields.
! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 15:48'!
product: aProduct
	product := aProduct! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:09'!
renderContentOn: html
	self renderMessagesOn: html.
	html form: [
		fields do: [:f | html render: f].
		html div: [
			html cancelButton value: 'Cancel'; callback: [ self answer: nil].
			html submitButton value: 'Save'; callback: [ self saveAndAnswer]
	]]! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:12'!
renderMessagesOn: html
	self valid ifFalse: [
		| messages |
		messages := OrderedCollection new.
		fields collect: [:f | messages addAll: f messages ].
		
		html unorderedList: [ 
			messages do: [ :m | html listItem: m]]]! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 15:48'!
saveAndAnswer
	self valid ifTrue: [ 
		fields do: [ :f| f save].
		self answer: product]! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 19:10'!
setupFields
	fields := OrderedCollection new.
	
	fields add: (WSField text 
		label: 'Name';
		on: #name of: product;
		beRequired).
	fields add: (WSField money
		label: 'Price';
		on: #price of: product;
		beRequired).
	fields add: (WSField largeText
		label: 'Description';
		on: #description of: product).! !

!WSProductEditor methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 15:45'!
valid
	^fields allSatisfy: [:f| f valid]! !

WAComponent subclass: #WSProductList
	instanceVariableNames: 'store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Components'!

!WSProductList class methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 13:39'!
store: aStore
	^self basicNew 
		store: aStore;
		initialize;
		yourself.! !

!WSProductList methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 18:30'!
renderContentOn: html
	store products do: [ :p| (WSProductPreview for: p on: self) renderContentOn: html]! !

!WSProductList methodsFor: 'as yet unclassified' stamp: 'srh 12/29/2008 18:28'!
store: aStore
	store := aStore.! !

WAComponent subclass: #WSStoreAdmin
	instanceVariableNames: 'store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Admin'!

!WSStoreAdmin class methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 11:51'!
canBeRoot
	^true! !

!WSStoreAdmin methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 12:01'!
initialize
	|r|
	super initialize.
	r := ReferenceStream fileNamed: 'demo_store'.
	store := r next.
	r close.! !

!WSStoreAdmin methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 11:54'!
renderContentOn: html
	html heading level: 2;with: [
		html anchor 
			callback: [ self call: (WSManageProducts store: store)]; 
			with: 'Manage Products'	]! !

TestCase subclass: #WSProductTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests'!

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:04'!
testAddFirstImageSetsPreview
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	self assert: i equals: p preview! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:03'!
testAddImage
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	self assert: p images includes: i.! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:53'!
testNewProduct
	|p|
	p := WSProduct new.
	self assert: p images isEmpty.! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:25'!
testPreviewMustBeInImages
	| p i1 i2 |
	p := WSProduct new.
	i1 := WSImage new.
	i2 := WSImage new.
	
	p addImage: i1.
	self should: [p preview: i2] raise: Exception whoseDescriptionIncludes: 'must be one of the product''s images'  description: 'Didn''t raise expected Exception'! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 14:03'!
testPriceInDollars
	self assert: 30.45 equals: (WSProduct new price: 3045;priceInDollars)! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:05'!
testRemoveImage
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	p removeImage: i.
	
	self assert: (p images includes: i) not.! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:18'!
testRemoveImageResetsPreview
	|p i1 i2|
	
	p := WSProduct new.
	i1 := WSImage new.
	i2 := WSImage new.
	p addImage: i1.
	p addImage: i2.
	p preview: i2.
	p removeImage: i2.
	
	self assert: i1 equals: p preview! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:07'!
testRemoveLastImageUnsetsPreview
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	p removeImage: i.
	
	self assert: p preview isNil..! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:18'!
testSetPreview
	|p i1 i2|
	p := WSProduct new.
	i1 := WSImage new.
	i2 := WSImage new.
	p addImage: i1.
	p addImage: i2.
	p preview: i2.
	
	self assert: i2 equals: p preview! !

TestCase subclass: #WSStoreTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStore-Tests'!

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 14:42'!
testAddProduct
	| s p |
	s := WSStore new.
	p := WSProduct new.
	s addProduct: p.
	self assert: (s products includes: p).
	! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 14:46'!
testDeleteProduct
	| s p |
	s := WSStore new.
	p := WSProduct new.
	s addProduct: p.
	s deleteProduct: p.
	self assert: (s products includes: p) not	! !
WSImage initialize!
